SharedCompressorPool

Struct SharedCompressorPool 

pub struct SharedCompressorPool { /* private fields */ }
A pool of shared compressors for the Shared compression mode

This pool allows multiple connections to share compressor instances, reducing memory usage when you have many connections.

Implementations

Source

impl SharedCompressorPool

pub fn new(config: DeflateConfig) -> Self

Create a new shared compressor pool

pub fn compress(&self, data: &[u8]) -> Result<Option<Bytes>>

Compress data using a pooled encoder

pub fn config(&self) -> &DeflateConfig

Get the pool’s configuration