CompressionContext

Enum CompressionContext 

pub enum CompressionContext {
    Disabled,
    Dedicated(DeflateContext),
    Shared {
        pool: Arc<SharedCompressorPool>,
        decoder: DeflateDecoder,
        config: DeflateConfig,
    },
}
A compression context that can be either dedicated or shared

Variants



Disabled

No compression



Dedicated(DeflateContext)

Dedicated per-connection compressor



Shared

Shared compressor from pool (encoder only, decoder is per-connection)

Implementations

Source

impl CompressionContext

pub fn server(mode: Compression) -> Self

Create a new compression context for the given mode (server role)

pub fn client(mode: Compression) -> Self

Create a new compression context for the given mode (client role)

pub fn with_shared_pool( pool: Arc<SharedCompressorPool>, is_server: bool, ) -> Self

Create a shared context that uses an existing pool

pub fn is_enabled(&self) -> bool

Check if compression is enabled

pub fn compress(&mut self, data: &[u8]) -> Result<Option<Bytes>>

Compress a message payload

Returns None if compression is disabled or if compression wouldn’t reduce size.

pub fn decompress(&mut self, data: &[u8], max_size: usize) -> Result<Bytes>

Decompress a message payload

pub fn config(&self) -> Option<&DeflateConfig>

Get the DeflateConfig for this context