pub struct SharedCompressorPool { /* private fields */ }Expand description
A pool of shared compressors for the Shared compression mode
This pool allows multiple connections to share compressor instances, reducing memory usage when you have many connections.
Implementations